@@ -1,5 +1,5 @@
 package Geo::Coder::OpenCage;
-$Geo::Coder::OpenCage::VERSION = '0.14';
+$Geo::Coder::OpenCage::VERSION = '0.15';
 use strict;
 use warnings;
 
@@ -26,13 +26,13 @@ sub new {
     return bless $self, $class;
 }
 
-# see list: https://geocoder.opencagedata.com/api#forward-opt
+# see list: https://opencagedata.com/api#forward-opt
 my %valid_params = (
     abbrv            => 1,
     add_request      => 1,
     bounds           => 1,
     countrycode      => 1,
-    format           => 0,    
+    format           => 0,
     jsonp            => 0,
     language         => 1,
     limit            => 1,
@@ -63,7 +63,7 @@ sub geocode {
         }
         if (!$params{$k}){  # is a real parameter but we dont support it
             warn "Unsupported geocode parameter: $k";
-            delete $params{$k};            
+            delete $params{$k};
         }
     }
 
@@ -75,8 +75,8 @@ sub geocode {
 
     my $response = $self->{ua}->get($URL);
 
-    if (!$response){ 
-        warn "failed to fetch '$URL': ", $response->{reason};        
+    if (!$response){
+        warn "failed to fetch '$URL': ", $response->{reason};
         return undef;
     }
 
@@ -89,7 +89,6 @@ sub geocode {
             . $rh_content->{status}{message};
         return undef;
     }
-   
     return $rh_content;
 }
 
@@ -122,7 +121,7 @@ Geo::Coder::OpenCage
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -134,7 +133,7 @@ version 0.14
 
 This module provides an interface to the OpenCage geocoding service.
 
-For full details of the API visit L<https://geocoder.opencagedata.com/api>.
+For full details of the API visit L<https://opencagedata.com/api>.
 
 =head1 NAME
 
@@ -146,7 +145,7 @@ Geo::Coder::OpenCage - Geocode coordinates and addresses with the OpenCage Geoco
 
     my $Geocoder = Geo::Coder::OpenCage->new(api_key => $my_api_key);
 
-Get your API key from L<https://geocoder.opencagedata.com>
+Get your API key from L<https://opencagedata.com>
 
 =head2 geocode
 
@@ -162,8 +161,8 @@ The OpenCage Geocoder has a few optional parameters
 
 =item Supported Parameters
 
-please see L<the OpenCage geocoder documentation|https://geocoder.opencagedata.com/api>. Most of 
-L<the various optional parameters|https://geocoder.opencagedata.com/api#forward-opt> are supported. For example:
+please see L<the OpenCage geocoder documentation|https://opencagedata.com/api>. Most of
+L<the various optional parameters|https://opencagedata.com/api#forward-opt> are supported. For example:
 
 =over 2
 
@@ -174,7 +173,7 @@ Portuguese); if this is omitted a code of en (English) will be assumed.
 
 =item limit
 
-Limits the maximum number of results returned. Default is 10.  
+Limits the maximum number of results returned. Default is 10.
 
 =item countrycode
 
@@ -182,8 +181,7 @@ Provides the geocoder with a hint to the country that the query resides in.
 This value will help the geocoder but will not restrict the possible results to
 the supplied country.
 
-The country code is a comma seperated list of 2 character code as defined by 
-the ISO 3166-1 Alpha 2standard.
+The country code is a comma seperated list of 2 character code as defined by the ISO 3166-1 Alpha 2 standard.
 
 =back
 
@@ -214,29 +212,31 @@ Takes two named parameters 'lat' and 'lng' and returns a result hashref.
 
     my $result = $Geocoder->reverse_geocode(lat => -22.6792, lng => 14.5272);
 
-This method supports the optional parameters in the same way that geocode() 
-does.
+This method supports the optional parameters in the same way that geocode() does.
 
 =head1 ENCODING
 
-All strings passed to and recieved from Geo::Coder::OpenCage methods are 
+All strings passed to and recieved from Geo::Coder::OpenCage methods are
 expected to be character strings, not byte strings.
 
 For more information see L<perlunicode>.
 
 =head1 SEE ALSO
 
-This module was featured in the 2016 Perl Advent Calendar. L<Read the article|http://perladvent.org/2016/2016-12-08.html>.
+This module was L<featured in the 2016 Perl Advent Calendar|http://perladvent.org/2016/2016-12-08.html>.
+
+Ed Freyfogle from the OpenCage team gave L<an interview with Built in Perl about how Perl is used at OpenCage|http://blog.builtinperl.com/post/opencage-data-geocoding-in-perl>.
 
 =head1 AUTHOR
 
-Ed Freyfogle 
+Ed Freyfogle
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2017 OpenCage Data Ltd <cpan@opencagedata.com>
 
-Please check out all our open source work over at L<https://github.com/opencagedata> and our developer blog: L<https://blog.opencagedata.com>
+Please check out all our open source work over at L<https://github.com/opencagedata>
+and our developer blog: L<https://blog.opencagedata.com>
 
 Thanks!
 
@@ -250,7 +250,7 @@ edf <edf@opencagedata.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by OpenCage Data Limited.
+This software is copyright (c) 2018 by OpenCage Data Limited.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
